<?php

/**
  * Shipping tab for admin panel, AdminShipping.php
  * @category admin
  *
  * @author PrestaShop <support@prestashop.com>
  * @copyright PrestaShop
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.8
  *
  */

class AdminShipping extends AdminTab
{
	private $_fieldsHandling;
	
	public function __construct()
	{
	 	$this->table = 'delivery';
 		
 		$this->_fieldsHandling = array(
		'PS_SHIPPING_HANDLING' => array('title' => $this->l('Handling charges'), 'suffix' => '&euro;', 'validation' => 'isFloat', 'cast' => 'floatval'),
		'PS_SHIPPING_FREE_PRICE' => array('title' => $this->l('Free shipping from'), 'suffix' => '&euro;', 'validation' => 'isFloat', 'cast' => 'floatval'),
		'PS_SHIPPING_FREE_WEIGHT' => array('title' => $this->l('Free shipping from'), 'suffix' => 'kg', 'validation' => 'isFloat', 'cast' => 'floatval'),
		'PS_SHIPPING_METHOD' => array('title' => $this->l('Billing'), 'validation' => 'isBool', 'cast' => 'intval'));
	
		parent::__construct();
	}
	
	public function postProcess()
	{
		global $currentIndex;

		/* Handling settings */
		if (isset($_POST['submitHandling'.$this->table]))
		{	
		 	/* Check required fields */
			foreach ($this->_fieldsHandling AS $field => $values)
				if (($value = Tools::getValue($field)) == false AND (string)$value != '0')
					$this->_errors[] = Tools::displayError('field').' <b>'.$values['title'].'</b> '.Tools::displayError('is required');
				
			/* Check field validity */
			foreach ($this->_fieldsHandling AS $field => $values)
				if (Tools::getValue($field))
				{
					$function = $values['validation'];
					if (!Validate::$function(Tools::getValue($field)))
						$this->_errors[] = Tools::displayError('field').' <b>'.$values['title'].'</b> '.Tools::displayError('is invalid');
				}
				
			/* Update configuration values */
			if (!sizeof($this->_errors))
			{			
				foreach ($this->_fieldsHandling AS $field => $values)
				{
					$function = $values['cast'];
					Configuration::updateValue($field, call_user_func($function, Tools::getValue($field)));
				}

				Tools::redirectAdmin($currentIndex.'&conf=6');
			}
		}
		
		/* Shipping fees */
		elseif (isset($_POST['submitFees'.$this->table]))
		{
			if (($id_carrier = intval(Tools::getValue('id_carrier'))) AND $id_carrier == ($id_carrier2 = intval(Tools::getValue('id_carrier2'))))
			{
				$carrier = new Carrier($id_carrier);
				if (Validate::isLoadedObject($carrier))
				{
				 	/* Get configuration values */
					$shipping_method = intval(Configuration::get('PS_SHIPPING_METHOD'));
					
					$rangeTable = $shipping_method ? 'range_weight' : 'range_price';
					$carrier->deleteDeliveryPrice($rangeTable);				
					
					/* Build prices list */
					$priceList = '';
					foreach ($_POST AS $key => $value)
						if (strstr($key, 'fees_'))
						{
							$tmpArray = explode('_', $key);
							$priceList .= '('.($shipping_method == 0 ? intval($tmpArray[2]) : 'NULL').', 
							'.($shipping_method == 1 ? intval($tmpArray[2]) : 'NULL').', '.$carrier->id.', 
							'.intval($tmpArray[1]).', '.number_format($value, 2, '.', '').'),';
							unset($tmpArray);
						}
					$priceList = rtrim($priceList, ',');
					
					/* Update delivery prices */
					$carrier->addDeliveryPrice($priceList);
				}
				else
					$this->_errors[] = Tools::displayError('an error occured while updating fees (cannot load carrier object)');
			}
			elseif (isset($id_carrier2))
			{
				$_POST['id_carrier'] = $id_carrier2;
			}
			else
				$this->_errors[] = Tools::displayError('an error occured while updating fees (cannot load carrier object)');
		}
	}

	public function display()
	{
		$this->displayFormHandling();
		$this->displayFormFees();
	}
	
	public function displayFormHandling()
	{
		global $currentIndex;
		
		$confKeys = $this->_fieldsHandling;
		foreach ($confKeys AS $key => $confKey)
			$getConf[] = $key;
		$confValues = Configuration::getMultiple($getConf);
		unset($confKeys['PS_SHIPPING_METHOD']);
		
		echo '
		<form action="'.$currentIndex.'&submitHandling'.$this->table.'=1" method="post">
			<fieldset>
				<legend><img src="../img/admin/delivery.gif" />'.$this->l('Handling').'</legend>';
		
		foreach ($confKeys AS $key => $confKey)
		{
			$postValue = Tools::getValue($key);
			echo '
			<label>'.$confKey['title'].':</label>
			<div class="margin-form">
				<input size="5" type="text" name="'.$key.'" value="'.
				(($postValue != false OR (string)$postValue == '0') ? $postValue : $confValues[$key]).'" /> '.$confKey['suffix'].'
			</div>';
		}
			
		echo '
				<label>'.$this->l('Billing:').' </label>
				<div class="margin-form">
					<input type="radio" name="PS_SHIPPING_METHOD" value="0" id="total_price"
					'.((isset($confValues['PS_SHIPPING_METHOD']) AND $confValues['PS_SHIPPING_METHOD'] == 0) ? 'checked="checked"' : '').'/>
					<label class="t" for="total_price"> '.$this->l('According to total price').'</label><br />
					<input type="radio" name="PS_SHIPPING_METHOD" value="1" id="total_weight"
					'.((!isset($confValues['PS_SHIPPING_METHOD']) OR $confValues['PS_SHIPPING_METHOD'] == 1) ? 'checked="checked"' : '').'/>
					<label class="t" for="total_weight"> '.$this->l('According to total weight').'</label>
				</div>
				<div class="margin-form">
					<input type="submit" value="'.$this->l('   Save   ').'" name="submitHandling'.$this->table.'" class="button" />
				</div>
			</fieldset>
		</form>';
	}
	
	public function displayFormFees()
	{
		global $currentIndex;
		
		echo '<br /><br />
		<h2>'.$this->l('Fees by carrier, geographical zone and ranges').'</h2>
		<form action="'.$currentIndex.'" id="fees" name="fees" method="post">
			<fieldset>
				<legend><img src="../img/admin/delivery.gif" />'.$this->l('Fees').'</legend>
				<b>'.$this->l('Carrier:').' </b> 
				<select name="id_carrier2" onchange="document.fees.submit();">';

		$carriers = Carrier::getCarriers(intval(Configuration::get('PS_LANG_DEFAULT')));
		$id_carrier = Tools::getValue('id_carrier') ? intval(Tools::getValue('id_carrier')) : intval($carriers[0]['id_carrier']);
		foreach ($carriers AS $carrier)
			echo '<option value="'.intval($carrier['id_carrier']).'"'.(($carrier['id_carrier'] == $id_carrier) ? ' selected="selected"' : '').'>'.$carrier['name'].'</option>';
		echo '
				</select><br />
				<table class="table space" cellpadding="0" cellspacing="0">
					<tr>
						<th>'.$this->l('Zone / Range').'</th>';	
				
				$shipping_method = intval(Configuration::get('PS_SHIPPING_METHOD'));
				$rangeObj = $shipping_method ? new RangeWeight() : new RangePrice();
				$rangeTable = $shipping_method ? 'range_weight' : 'range_price';
				$rangeIdentifier = 'id_'.$rangeTable;
				$ranges = $rangeObj->getRanges();
				$suffix = $shipping_method ? 'kg' : '&euro;';
				$delivery = Carrier::getDeliveryPriceByRanges($rangeTable);
				foreach ($delivery AS $deliv)
					$deliveryArray[$deliv['id_zone']][$deliv['id_carrier']][$deliv[$rangeIdentifier]] = $deliv['price'];
				foreach ($ranges AS $range)
					echo '<th style="font-size: 11px;">'.floatval($range['delimiter1']).$suffix.' '.$this->l('to').' '.floatval($range['delimiter2']).$suffix.'</th>';
				echo '</tr>';
				
				$zones = Zone::getZones(true);
				foreach ($zones AS $zone)
				{
					echo '
					<tr>
						<th style="height: 30px;">'.$zone['name'].'</th>';
					foreach ($ranges AS $range)
					{
						if (isset($deliveryArray[$zone['id_zone']][$id_carrier][$range[$rangeIdentifier]]))
							$price = $deliveryArray[$zone['id_zone']][$id_carrier][$range[$rangeIdentifier]];
						else
							$price = '0.00';
						echo '<td class="center"><input type="text" name="fees_'.$zone['id_zone'].'_'.$range[$rangeIdentifier].'" value="'.$price.'" style="width: 45px;" /> &euro;</td>';
					}
					echo '
					</tr>';
				}
				
				echo '
					<tr>
						<td colspan="'.(sizeof($ranges) + 1).'" class="center" style="border-bottom: none; height: 40px;">
							<input type="hidden" name="submitFees'.$this->table.'" value="1" />
							<input type="submit" value="'.$this->l('   Save   ').'" class="button" />
						</td>
					</tr>
				</table>
			</fieldset>
			<input type="hidden" name="id_carrier" value="'.$id_carrier.'" />
		</form>';
	}
}

?>