<?php

/**
  * Access class, Access.php
  * Access
  * @category classes
  *
  * @author PrestaShop <support@prestashop.com>
  * @copyright PrestaShop
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.8
  *
  */

class		Access extends ObjectModel
{
	/** @var integer */
	public $id_access;
	
	/** @var integer */
	public $id_profile;

	/** @var integer */
	public $id_tab;

	/** @var bool */
	public $view;

	/** @var bool */
	public $add;

	/** @var bool */
	public $edit;

	/** @var bool */
	public $delete;

	/** @var array tabs */
	private	$tabs;
	
	/** @var array profiles */
	private	$profiles;
	
	/** @var array accesses */
	private	$accesses = array();

	protected	$fieldsRequired = array ('id_profile', 'id_tab', 'view', 'add', 'edit', 'delete');	
	protected	$fieldsValidate = array ('id_profile' => 'isUnsignedId', 'id_tab' => 'isUnsignedId', 'view' => 'isBool', 'add' => 'isBool', 'edit' => 'isBool', 'delete' => 'isBool');

	protected 	$table = 'access';
	protected 	$identifier = 'id_access';

	public function getFields()
	{
		parent::validateFields();
		
		$fields['id_profile'] = intval($this->id_profile);
		$fields['view'] = intval ($this->view);
		$fields['add'] = intval($this->add);
		$fields['edit'] = intval($this->edit);
		$fields['delete'] = intval($this->delete);
		
		return $fields;
	}	


	/**
	 * Get Access for a profile and a specific tab
	 *
	 * @param integer profile id
	 * @param integer tab id
	 * @return array accesses
	 */
	public	function getProfileAccess($id_profile, $id_tab)
	{
	 	/* Accesses selection */
	 	$this->access = Db::getInstance ()->getRow('SELECT `view`, `add`, `edit`, `delete` FROM `'._DB_PREFIX_.'access` WHERE `id_profile` = '.intval($id_profile).' AND `id_tab` = '.intval($id_tab));
	 	
		return $this->access;
	}

	/**
	 * Get Accesses for a profile
	 *
	 * @param string profile id
	 * @return array accesses
	 */
	public	function getProfileAccesses($id_profile)
	{
	 	/* Accesses selection */
	 	$this->accesses = Db::getInstance ()->ExecuteS('SELECT `id_tab`, `view`, `add`, `edit`, `delete` FROM `'._DB_PREFIX_.'access` WHERE `id_profile` = '.intval($id_profile));
	 	
	 	$result = array();
	 	/* For each access */
	 	if (!$this->accesses)
	 	{
		 	$this->_error[] = 'No access for this profile';
		 	return false;
	 	}
		foreach($this->accesses AS $access) {
		 	/* If it is the first time we meet this tab we prepare it */
		 	if (!isset($result[$access['id_tab']]))
		 		$result[$access['id_tab']] = array();
			$result[$access['id_tab']] = $access;
		}
		
		return $result;
	}

	/**
	 * Update access for a profile and a tab
	 *
	 * @param integer profile id
	 * @param integer tab id
	 * @param string action
	 * @param integer status
	 */
	public	function updateProfileAccess($id_profile, $id_tab, $action, $status)
	{
		Db::getInstance ()->Execute('UPDATE `'._DB_PREFIX_.'access` SET `'.$action.'` = '.intval($status).' WHERE `id_profile` = '.intval($id_profile).' AND `id_tab` = '.intval($id_tab));
	}
	
	public function tmp()
	{
	 	for ($i = 0; $i < 3; $i++)
	 		for ($j = 0; $j < 32; $j++)
	 	 		Db::getInstance ()->Execute('INSERT INTO `'._DB_PREFIX_.'access` VALUES(\'\', '.intval($i + 1).', '.intval($j + 1).', 1, 1, 1, 1)');
	}
	
	/**
	 * Access inputs
	 *
	 */
	public function printTabAccess($currentProfile, $tab, $access, $is_child)
	{
		echo '<tr>
				 <td'.($is_child ? '' : ' class="bold"').'>'.($is_child ? ' &raquo; ' : '').$tab['name'].'</td>
				 <td class="center"><input type="checkbox" name="1" onchange="ajax_power(this, \'view\', \''.$currentProfile.'\', '.$tab['id_tab'].')" '.($access['view'] === '1' ? 'checked="checked"' : '').'/></td>
				 <td class="center"><input type="checkbox" name="1" onchange="ajax_power(this, \'add\', \''.$currentProfile.'\', '.$tab['id_tab'].')" '.($access['add'] === '1' ? 'checked="checked"' : '').'/></td>
				 <td class="center"><input type="checkbox" name="1" onchange="ajax_power(this, \'edit\', \''.$currentProfile.'\', '.$tab['id_tab'].')" '.($access['edit'] === '1' ? 'checked="checked"' : '').'/></td>
				 <td class="center"><input type="checkbox" name="1" onchange="ajax_power(this, \'delete\', \''.$currentProfile.'\', '.$tab['id_tab'].')" '.($access['delete'] === '1' ? 'checked="checked"' : '').'/></td>
			 </tr>';
	 
	}
}
?>