<?php
/**
  * PDF class, PDF.php
  * PDF invoices and document management
  * @category classes
  *
  * @author PrestaShop <support@prestashop.com>
  * @copyright PrestaShop
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.8
  *
  */

include(_PS_FPDF_PATH_.'fpdf.php');

class PDF extends FPDF
{
 	/** @var object Customer Order object */
	private static $order = NULL;

	/** @var object Order currency object */
	private static $currency = NULL;

	private static $_iso;
	/** @var array Translations chosen for display invoice */
	private static $_translations = array (
		'FR' => array(
			'INVOICE #' => 'FACTURE N°FA',
			'You can also see your order state in "My Account" section on our website' => 'Vous pouvez également suivre votre commande dans la rubrique "mon compte" de notre site internet.',
			'Product' => 'Produit',
			'Qty' => 'Qté',
			'Ref' => 'Réf',
			'Tax' => 'Taxe',
			'Price' => 'Prix HT',
			'Price TI' => 'Prix TTC',
			'Total TI' => 'Total TTC',
			'Discount' => 'Réduction',
			'Total products' => 'Total produits',
			'Total discounts' => 'Total bons d\'achat et réductions',
			'Total shipping' => 'Frais d\'expédition',
			'Informations' => 'Informations',
			'Delivery' => 'Livraison',
			'Invoicing' => 'Facturation',
			'Order date' => 'Date de commande',
			'Payment method' => 'Mode de paiement',
			'Invoice reference' => 'Référence de la facture',
			'Carrier' => 'Transporteur',
			'Order details' => 'Détails de la commande'
		)
	);
	
	/**
	* Invoice header
	*/
    function Header()
    {
     	$conf = Configuration::getMultiple(array('PS_SHOP_NAME', 'PS_SHOP_ADDR1', 'PS_SHOP_CODE', 'PS_SHOP_CITY', 'PS_SHOP_COUNTRY'));
		$conf['PS_SHOP_NAME'] = isset($conf['PS_SHOP_NAME']) ? utf8_decode($conf['PS_SHOP_NAME']) : 'Your company';		
		$conf['PS_SHOP_ADDR1'] = isset($conf['PS_SHOP_ADDR1']) ? utf8_decode($conf['PS_SHOP_ADDR1']) : 'Your company';
		$conf['PS_SHOP_CODE'] = isset($conf['PS_SHOP_CODE']) ? utf8_decode($conf['PS_SHOP_CODE']) : 'Postcode';
		$conf['PS_SHOP_CITY'] = isset($conf['PS_SHOP_CITY']) ? utf8_decode($conf['PS_SHOP_CITY']) : 'City';
		$conf['PS_SHOP_COUNTRY'] = isset($conf['PS_SHOP_COUNTRY']) ? utf8_decode($conf['PS_SHOP_COUNTRY']) : 'Country';
		
		if (file_exists(_PS_IMG_DIR_.'/logo.jpg'))
            $this->Image(_PS_IMG_DIR_.'/logo.jpg', 10, 8, 0, 15);
        $this->SetFont('Arial', 'B', 15);
        $this->Cell(80);
        $this->Cell(105, 10, self::l('INVOICE #').sprintf('%06d', self::$order->id), 1, 0, 'C');
        $this->Ln(12);
        $this->SetFont('Arial', 'B', 10);
		$this->Cell(0, 12, $conf['PS_SHOP_NAME'], 0, 'L');
		$this->Ln(8);
        $this->Cell(0, 10, $conf['PS_SHOP_ADDR1'], 0, 'L');
        $this->Ln(5);
		if (!empty($conf['PS_SHOP_ADDR2'])) {
		    $this->Cell(0, 10, $conf['PS_SHOP_ADDR2'], 0, 'L');
			$this->Ln(5);
		}
        $this->Cell(0, 10, $conf['PS_SHOP_CODE'].' '.$conf['PS_SHOP_CITY'], 0, 'L');
        $this->Ln(6);
        $this->Cell(0, 8, strtoupper($conf['PS_SHOP_COUNTRY']), 0, 'L');
    }

	/**
	* Invoice footer
	*/
    function Footer()
    {
        $this->SetFont('Arial', 'B', 9);
        $this->SetY(-25);
        $this->Cell(0, 10, self::l('You can also see your order state in "My Account" section on our website'), 0, 'L', NULL, NULL, 'http://'.$_SERVER['SERVER_NAME'].__PS_BASE_URI__.'history.php');
        $this->SetY(-18);
        $this->Line(10, 283, 200, 283);
        $this->SetY(-15);
        $this->SetTextColor(100, 100, 100);
		
		$conf = Configuration::getMultiple(array('PS_SHOP_NAME', 'PS_SHOP_ADDR1', 'PS_SHOP_CODE', 'PS_SHOP_CITY', 'PS_SHOP_COUNTRY'));
		$conf['PS_SHOP_ADDR1'] = isset($conf['PS_SHOP_ADDR1']) ? $conf['PS_SHOP_ADDR1'] : 'Your company';
		$conf['PS_SHOP_ADDR2'] = isset($conf['PS_SHOP_ADDR2']) ? $conf['PS_SHOP_ADDR2'] : '';
		$conf['PS_SHOP_CODE'] = isset($conf['PS_SHOP_CODE']) ? $conf['PS_SHOP_CODE'] : 'Postcode';
		$conf['PS_SHOP_CITY'] = isset($conf['PS_SHOP_CITY']) ? $conf['PS_SHOP_CITY'] : 'City';
		$conf['PS_SHOP_COUNTRY'] = isset($conf['PS_SHOP_COUNTRY']) ? $conf['PS_SHOP_COUNTRY'] : 'Country';
		$conf['PS_SHOP_RCS'] = isset($conf['PS_SHOP_RCS']) ? $conf['PS_SHOP_RCS'] : 'RCS';
		if (!empty($conf['PS_SHOP_ADDR2']))
			$conf['PS_SHOP_ADDR1'] .= " ".$conf['PS_SHOP_ADDR2'];
        $this->Cell(0, 10, utf8_decode($conf['PS_SHOP_NAME'].' - '.$conf['PS_SHOP_ADDR1'].' - '.$conf['PS_SHOP_CODE'].' '.$conf['PS_SHOP_CITY'].' - '.strtoupper($conf['PS_SHOP_COUNTRY']). ((isset($conf['PS_SHOP_RCS']) && !empty($conf['PS_SHOP_RCS'])) ? ' - '.$conf['PS_SHOP_RCS'] : '')), 0, 0, 'C');
    }

	/**
	* Product table with price, quantities...
	*/
    function ProdTab()
    {
        $header = array(self::l('Product'), self::l('Qty'), self::l('Ref'), self::l('Tax'), self::l('Price'), self::l('Price TI'), self::l('Total TI'));
        $w = array(86, 15, 18, 11, 20, 20, 20);
        $this->SetFont('Arial', 'B', 9);
        for($i = 0; $i < count($header); $i++)
            $this->Cell($w[$i], 8, $header[$i], 1, 0, 'C');
        $this->Ln();
        $this->SetFont('Arial', '', 7);
		$products = self::$order->getProducts();
        foreach($products AS $product)
        {
            $price = $product['product_price'];
            $total_price = $price * $product['product_quantity'];
            $price_with_taxe = $product['product_price_wt'];
            $total_with_taxe = $price_with_taxe * $product['product_quantity'];
            
			$before = $this->GetY();
            $this->MultiCell($w[0], 6, utf8_decode($product['product_name']), 'LR', 'L');
			$lineSize = $this->GetY() - $before;
			$this->SetXY($this->GetX() + $w[0], $this->GetY() - $lineSize);
            $this->Cell($w[1], $lineSize, $product['product_quantity'], 'LR');
            $this->Cell($w[2], $lineSize, substr($product['product_reference'], 0, 11), 'LR');
            $this->Cell($w[3], $lineSize, number_format($product['tax_rate'], 2, ',', ' ').'%', 'LR', 0, 'R');
            $this->Cell($w[4], $lineSize, self::euro(Tools::displayPrice($price, self::$currency, true)), 'LR', 0, 'R');
            $this->Cell($w[5], $lineSize, self::euro(Tools::displayPrice($price_with_taxe, self::$currency, true)), 'LR', 0, 'R');
            $this->Cell($w[6], $lineSize, self::euro(Tools::displayPrice($total_with_taxe, self::$currency, true)), 'LR', 0, 'R');
            $this->Ln();
        }

        if (!sizeof(self::$order->getDiscounts()))
            $this->Cell(array_sum($w), 0, '', 'T');
    }
    
    /**
	* Discount table with value, quantities...
	*/
    function DiscTab()
    {
        $w = array(86, 15, 18, 11, 20, 20, 20);

        $this->SetFont('Arial', 'B', 7);
		$discounts = self::$order->getDiscounts();
        foreach($discounts AS $discount)
        {
            $this->Cell($w[0], 6, self::l('Discount').' : '.$discount['name'], 'LR');
            $this->Cell($w[1], 6, '1', 'LR');
            $this->Cell($w[2], 6, '', 'LR');
            $this->Cell($w[3], 6, '', 'LR', 0, 'R');
            $this->Cell($w[4], 6, '', 'LR', 0, 'R');
            $this->Cell($w[5], 6, '', 'LR', 0, 'R');
            $this->Cell($w[6], 6, '-'.self::euro(Tools::displayPrice($discount['value'], self::$currency, true)), 'LR', 0, 'R');
            $this->Ln();
        }

        if (sizeof($discounts))
            $this->Cell(array_sum($w), 0, '', 'T');
    }
	
	/**
	* Main
	*
	* @param object $order Order
	* @param string $mode Download or display (optional)
	*/
	public static function invoice($order, $mode = 'D')
	{
	 	global $cookie;

		if (!Validate::isLoadedObject($order) OR (!isset($cookie->id_employee) AND !OrderState::invoiceAvailable($order->getCurrentState())))
			return false;
		self::$order = $order;
		self::$_iso = strtoupper(Language::getIsoById(intval(self::$order->id_lang)));
		self::$currency = new Currency(intval(self::$order->id_currency));
		
		$pdf = new PDF('P', 'mm', 'A4');
		$pdf->AliasNbPages();
		$pdf->AddPage();

		$pdf->SetX(10);
		$pdf->SetY(30);
		$pdf->SetFont('Arial', 'B', 11);
		$pdf->Ln(25);

		$pdf->SetFillColor(230, 230, 230);
		$pdf->Cell(0, 8, self::l('Delivery').' & '.self::l('Invoicing'), 0, 2, 'L', 1);

		$invoice_address = new Address($order->id_address_invoice);
		$delivery_address = new Address($order->id_address_delivery);
		$pdf->SetFont('Arial', 'BU', 10);
		$pdf->Cell(80, 10, self::l('Invoicing'), 0, 'L');
		$pdf->Cell(80, 10, self::l('Delivery'), 0, 'L');
		$pdf->Ln(6);
		$pdf->SetFont('Arial', '', 10);
		$pdf->Cell(80, 10, utf8_decode($invoice_address->company), 0, 'L');
		$pdf->Cell(80, 10, utf8_decode($delivery_address->company), 0, 'L');
		$pdf->Ln(5);
		$pdf->Cell(80, 10, utf8_decode($invoice_address->surname).' '.utf8_decode($invoice_address->name), 0, 'L');
		$pdf->Cell(80, 10, utf8_decode($delivery_address->surname).' '.utf8_decode($delivery_address->name), 0, 'L');
		$pdf->Ln(5);
		$pdf->Cell(80, 10, utf8_decode($invoice_address->address1), 0, 'L');
		$pdf->Cell(80, 10, utf8_decode($delivery_address->address1), 0, 'L');
		$pdf->Ln(5);
		if (!empty($invoice_address->address2) OR !empty($delivery_address->address2))
		{
		    $pdf->Cell(80, 10, utf8_decode($invoice_address->address2), 0, 'L');
		    $pdf->Cell(80, 10, utf8_decode($delivery_address->address2), 0, 'L');
		    $pdf->Ln(5);
		}
		$pdf->Cell(80, 10, $invoice_address->postcode.' '.utf8_decode($invoice_address->city), 0, 'L');
		$pdf->Cell(80, 10, $delivery_address->postcode.' '.utf8_decode($delivery_address->city), 0, 'L');
		$pdf->Ln(5);
		$pdf->Cell(80, 10, $invoice_address->country, 0, 'L');
		$pdf->Cell(80, 10, $delivery_address->country, 0, 'L');

		$pdf->SetFont('Arial', 'B', 11);
		$pdf->Ln(15);
		$pdf->SetFillColor(230, 230, 230);
		$pdf->Cell(0, 8, self::l('Informations'), 0, 2, 'L', 1);
		$pdf->SetFont('Arial', '', 10);

		$pdf->Cell(0, 10, self::l('Order date').' : '.Tools::displayDate(self::$order->date_add, self::$order->id_lang, true), 0, 'L');
		$pdf->Ln(5);
		$pdf->Cell(0, 10, self::l('Payment method').' : '.html_entity_decode(self::$order->payment), 0, 'L');
		$pdf->Ln(5);
		$pdf->Cell(0, 10, self::l('Invoice reference').' : '.sprintf('%06d', self::$order->id), 0, 'L');
		$pdf->Ln(5);
		$carrier = new Carrier(self::$order->id_carrier);
		$pdf->Cell(0, 10, self::l('Carrier').' : '.$carrier->name, 0, 'L');
		$pdf->Ln(15);

		$pdf->SetFont('Arial', 'B', 11);
		$pdf->SetFillColor(230, 230, 230);
		$pdf->Cell(0, 8, self::l('Order details'), 0, 2, 'L', 1);
		$pdf->Ln(5);
		$pdf->SetFont('Arial', '', 10);

		$pdf->ProdTab();
		$pdf->DiscTab();

		$pdf->SetFont('Arial', 'B', 11);
		$pdf->Ln(6);
		$pdf->Cell(190, 0, self::l('Total products').' : '.self::euro(Tools::displayPrice(self::$order->getTotalProductsWithTaxes(), self::$currency, true)), 'LR', 0, 'R');
		$pdf->Ln(6);
		$pdf->Cell(190, 0, self::l('Total discounts').' : '.self::euro(Tools::displayPrice(self::$order->total_discounts, self::$currency, true)), 'LR', 0, 'R');
		$pdf->Ln(6);
		$pdf->Cell(190, 0, self::l('Total shipping').' : '.self::euro(Tools::displayPrice(self::$order->total_shipping, self::$currency, true)), 'LR', 0, 'R');
		$pdf->Ln(6);
		$pdf->Cell(190, 0, self::l('Total TI').' : '.self::euro(Tools::displayPrice(self::$order->total_paid, self::$currency, true)), 'LR', 0, 'R');

		return $pdf->Output(sprintf('%06d', self::$order->id).'.pdf', $mode);
	}
	
	static private function euro($s)
	{
		return str_replace('&euro;', chr(128), $s);
	}
	
	static private function l($key)
	{
		return ((key_exists(self::$_iso, self::$_translations) AND key_exists($key, self::$_translations[self::$_iso])) ? utf8_decode(self::$_translations[self::$_iso][$key]) : utf8_decode($key));
	}
}

?>